Module local_runtime

Module local_runtime 

Local Docker runtime — manages bash sessions and file operations inside a container by shelling out to docker exec.

Ports the Python LocalRuntime class.

Structs

LocalRuntime
Local runtime that manages bash sessions and file operations.